pub struct Builder { /* private fields */ }Expand description
Accumulates SPIR-V words per section and hands out result ids.
Implementations
Sourceimpl Builder
impl Builder
pub fn new() -> Self
Sourcepub fn inst(&mut self, s: Section, op: u16, operands: &[u32])
pub fn inst(&mut self, s: Section, op: u16, operands: &[u32])
Emit one instruction with no result id.
Sourcepub fn typed(
&mut self,
s: Section,
op: u16,
result_type: u32,
rest: &[u32],
) -> u32
pub fn typed( &mut self, s: Section, op: u16, result_type: u32, rest: &[u32], ) -> u32
Emit one instruction whose operands are [result_type, result_id, ..rest] and return result_id.
Sourcepub fn result(&mut self, s: Section, op: u16, rest: &[u32]) -> u32
pub fn result(&mut self, s: Section, op: u16, rest: &[u32]) -> u32
Emit one instruction whose only leading operand is its result id
(OpTypeInt, OpLabel, …) and return that id.